Index: xml-xerces/java/src/org/apache/xerces/dom3/DOMConfiguration.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/DOMConfiguration.java,v
retrieving revision 1.1
diff -u -w -r1.1 DOMConfiguration.java
--- xml-xerces/java/src/org/apache/xerces/dom3/DOMConfiguration.java	11 Dec 2002 16:14:30 -0000	1.1
+++ xml-xerces/java/src/org/apache/xerces/dom3/DOMConfiguration.java	29 Jul 2003 12:47:31 -0000
@@ -1,331 +1,352 @@
 /*
- * Copyright (c) 2002 World Wide Web Consortium,
- * (Massachusetts Institute of Technology, Institut National de
- * Recherche en Informatique et en Automatique, Keio University). All
- * Rights Reserved. This program is distributed under the W3C's Software
- * Intellectual Property License. This program is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
- * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.
- * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
+ * Copyright (c) 2003 World Wide Web Consortium,
+ *
+ * (Massachusetts Institute of Technology, European Research Consortium for
+ * Informatics and Mathematics, Keio University). All Rights Reserved. This
+ * work is distributed under the W3C(r) Software License [1] in the hope that
+ * it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * [1] http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
 package org.apache.xerces.dom3;
 
 import org.w3c.dom.DOMException;
-
 /**
- *  DOM Level 3 WD Experimental: The <code>DOMConfiguration</code> interface represents the configuration 
+ *  The <code>DOMConfiguration</code> interface represents the configuration
  * of a document and maintains a table of recognized parameters. Using the 
  * configuration, it is possible to change 
- * <code>Document.normalizeDocument</code> behavior, such as replacing the 
+ * <code>Document.normalizeDocument()</code> behavior, such as replacing the
  * <code>CDATASection</code> nodes with <code>Text</code> nodes or 
  * specifying the type of the schema that must be used when the validation 
  * of the <code>Document</code> is requested. <code>DOMConfiguration</code> 
- * objects are also used in [<a href='http://www.w3.org/TR/DOM-Level-3-LS'>DOM Level 3 Load and Save</a>] in the <code>DOMBuilder</code> and 
- * <code>DOMWriter</code> interfaces. 
- * <p> The <code>DOMConfiguration</code> distinguish two types of parameters: 
- * <code>boolean</code> (boolean parameters) and <code>DOMUserData</code> 
- * (parameters). The names used by the <code>DOMConfiguration</code> object 
+ * objects are also used in [<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030226'>DOM Level 3 Load and Save</a>]
+ *  in the <code>DOMParser</code> and <code>DOMSerializer</code> interfaces.
+ * <p> The parameter names used by the <code>DOMConfiguration</code> object
  * are defined throughout the DOM Level 3 specifications. Names are 
  * case-insensitives. To avoid possible conflicts, as a convention, names 
- * referring to boolean parameters and parameters defined outside the DOM 
- * specification should be made unique. Names are recommended to follow the 
- * XML name production rule but it is not enforced by the DOM 
- * implementation. DOM Level 3 Core Implementations are required to 
- * recognize all boolean parameters and parameters defined in this 
- * specification. Each boolean parameter state or parameter value may then 
- * be supported or not by the implementation. Refer to their definition to 
- * know if a state or a value must be supported or not.  Parameters are 
- * similar to features and properties used in SAX2 [<a href='http://www.saxproject.org/'>SAX</a>].  Can we rename boolean 
- * parameters to "flags"?  Are boolean parameters and parameters within the 
- * same scope for uniqueness? Which exception should be raised by 
- * <code>setBooleanParameter("error-handler", true)</code>? 
+ * referring to parameters defined outside the DOM specification should be
+ * made unique. Because parameters are exposed as properties in the , names
+ * are recommended to follow the section 5.16 Identifiers of [Unicode] with the addition of the character '-' (HYPHEN-MINUS) but it is not
+ * enforced by the DOM implementation. DOM Level 3 Core Implementations are
+ * required to recognize all parameters defined in this specification. Some
+ * parameter values may also be required to be supported by the
+ * implementation. Refer to the definition of the parameter to know if a
+ * value must be supported or not.
+ * <p ><b>Note:</b>  Parameters are similar to features and properties used in
+ * SAX2 [<a href='http://www.saxproject.org/'>SAX</a>].
  * <p> The following list of parameters defined in the DOM: 
  * <dl>
  * <dt>
- * <code>"error-handler"</code></dt>
- * <dd>[required] A <code>DOMErrorHandler</code> 
- * object. If an error is encountered in the document, the implementation 
- * will call back the <code>DOMErrorHandler</code> registered using this 
- * parameter.  When called, <code>DOMError.relatedData</code> will contain 
- * the closest node to where the error occured. If the implementation is 
- * unable to determine the node where the error occurs, 
- * <code>DOMError.relatedData</code> will contain the <code>Document</code> 
- * node. Mutations to the document from within an error handler will result 
- * in implementation dependent behaviour.  Should we say non "readonly" 
- * operations are implementation dependent instead?  Removed: "or 
- * re-invoking a validation operation". </dd>
- * <dt><code>"schema-type"</code></dt>
- * <dd>[optional] 
- * A <code>DOMString</code> object containing an absolute URI and 
- * representing the type of the schema language used to validate a document 
- * against. Note that no lexical checking is done on the absolute URI.  If 
- * this parameter is not set, a default value may be provided by the 
- * implementation, based on the schema languages supported and on the schema 
- * language used at load time.  For XML Schema [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>], applications must use the 
- * value <code>"http://www.w3.org/2001/XMLSchema"</code>. For XML DTD [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>], 
- * applications must use the value 
- * <code>"http://www.w3.org/TR/REC-xml"</code>. Other schema languages are 
- * outside the scope of the W3C and therefore should recommend an absolute 
- * URI in order to use this method. </dd>
- * <dt><code>"schema-location"</code></dt>
- * <dd>[optional] 
- * A <code>DOMString</code> object containing a list of URIs, separated by 
- * white spaces (characters matching the nonterminal production S defined in 
- * section 2.3 [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>]), that represents the schemas against which validation 
- * should occur. The types of schemas referenced in this list must match the 
- * type specified with <code>schema-type</code>, otherwise the behaviour of 
- * an implementation is undefined. If the schema type is XML Schema [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>], only 
- * one of the XML Schemas in the list can be with no namespace.  If 
- * validation occurs against a namespace aware schema, i.e. XML Schema, and 
- * the targetNamespace of a schema (specified using this property) matches 
- * the targetNamespace of a schema occurring in the instance document, i.e 
- * in schemaLocation attribute, the schema specified by the user using this 
- * property will be used (i.e., in XML Schema the <code>schemaLocation</code>
- *  attribute in the instance document or on the <code>import</code> element 
- * will be effectively ignored).  It is illegal to set the schema-location 
- * parameter if the schema-type parameter value is not set. It is strongly 
- * recommended that <code>DOMInputSource.baseURI</code> will be set, so that 
- * an implementation can successfully resolve any external entities 
- * referenced. </dd>
- * </dl>
- * <p> The following list of boolean parameters (features) defined in the DOM: 
- * <dl>
- * <dt>
  * <code>"canonical-form"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[optional]Canonicalize the 
- * document according to the rules specified in [<a href='http://www.w3.org/TR/2001/REC-xml-c14n-20010315'>Canonical XML</a>]. Note that this is limited 
- * to what can be represented in the DOM. In particular, there is no way to 
- * specify the order of the attributes in the DOM. What happen to other 
- * features? are they ignored? if yes, how do you know if a feature is 
- * ignored? </dd>
+ * <dd>[<em>optional</em>]Canonicalize the document according to the rules specified in [<a href='http://www.w3.org/TR/2001/REC-xml-c14n-20010315'>Canonical XML</a>].
+ * Note that this is limited to what can be represented in the DOM. In
+ * particular, there is no way to specify the order of the attributes in the
+ * DOM.This forces the following parameters to <code>false</code>: "entities
+ * ", "normalize-characters", "cdata-sections".This forces the following
+ * parameters to <code>true</code>: "namespaces", "namespace-declarations", "
+ * well-formed", "whitespace-in-element-content".Other parameters are not
+ * changed unless explicitly specified in the description of the parameters.
+ * In addition, the <code>DocumentType</code> node is removed from the tree
+ * if any and superfluous namespace declarations are removed from each
+ * element. Note that querying this parameter with <code>getParameter</code>
+ * cannot return <code>true</code> unless it has been set to
+ * <code>true</code> and the parameters described above are appropriately
+ * set.</dd>
  * <dt><code>false</code></dt>
- * <dd>[required] (default)Do not canonicalize the 
- * document.</dd>
+ * <dd>[<em>required</em>] (<em>default</em>)Do not canonicalize the document.</dd>
  * </dl></dd>
  * <dt><code>"cdata-sections"</code></dt>
  * <dd>
  * <dl>
- * <dt><code>true</code></dt>
- * <dd>[required] (default
- * )Keep <code>CDATASection</code> nodes in the document.Name does not work 
- * really well in this case. ALH suggests renaming this to "cdata-sections". 
- * It works for both load and save.Renamed as suggested. (Telcon 27 Jan 
- * 2002).</dd>
- * <dt><code>false</code></dt>
- * <dd>[required]Transform <code>CDATASection</code> 
- * nodes in the document into <code>Text</code> nodes. The new 
- * <code>Text</code> node is then combined with any adjacent 
- * <code>Text</code> node.</dd>
+ * <dt>
+ * <code>true</code></dt>
+ * <dd>[<em>required</em>] (<em>default</em>)Keep <code>CDATASection</code> nodes in the document.</dd>
+ * <dt><code>false</code></dt>
+ * <dd>[<em>required</em>]Transform <code>CDATASection</code> nodes in the document into
+ * <code>Text</code> nodes. The new <code>Text</code> node is then combined
+ * with any adjacent <code>Text</code> node.</dd>
  * </dl></dd>
- * <dt><code>"comments"</code></dt>
+ * <dt>
+ * <code>"check-character-normalization"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[required] 
- * (default)Keep <code>Comment</code> nodes in the document.</dd>
+ * <dd>[<em>optional</em>] Check if the characters in the document are fully normalized according
+ * to the rules defined in [<a href='http://www.w3.org/TR/2002/WD-charmod-20020430'>CharModel</a>]
+ * supplemented by the definitions of relevant constructs from <a href='http://www.w3.org/TR/2002/CR-xml11-20021015/#sec2.13'>Section 2.13</a> of [<a href='http://www.w3.org/TR/2002/CR-xml11-20021015/'>XML 1.1</a>]. </dd>
  * <dt>
  * <code>false</code></dt>
- * <dd>[required]Discard <code>Comment</code> nodes in the 
- * Document.</dd>
+ * <dd>[<em>required</em>] (<em>default</em>)Do not check if characters are normalized.</dd>
  * </dl></dd>
- * <dt><code>"datatype-normalization"</code></dt>
+ * <dt><code>"comments"</code></dt>
  * <dd>
  * <dl>
- * <dt><code>true</code></dt>
- * <dd>[required]
- * Let the validation process do its datatype normalization that is defined 
- * in the used schema language. Note that this does not affect the DTD 
- * normalization operation which always takes place, in accordance to [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>].We 
- * should define "datatype normalization".DTD normalization always apply 
- * because it's part of XML 1.0. Clarify the spec. (Telcon 27 Jan 2002).</dd>
  * <dt>
- * <code>false</code></dt>
- * <dd>[required] (default)Disable datatype normalization. The 
- * XML 1.0 attribute value normalization always occurs though.</dd>
+ * <code>true</code></dt>
+ * <dd>[<em>required</em>] (<em>default</em>)Keep <code>Comment</code> nodes in the document.</dd>
+ * <dt><code>false</code></dt>
+ * <dd>[<em>required</em>]Discard <code>Comment</code> nodes in the document.</dd>
  * </dl></dd>
  * <dt>
- * <code>"discard-default-content"</code></dt>
+ * <code>"datatype-normalization"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[required] (default
- * )Use whatever information available to the implementation (i.e. XML 
- * schema, DTD, the <code>specified</code> flag on <code>Attr</code> nodes, 
- * and so on) to decide what attributes and content should be discarded or 
- * not. Note that the <code>specified</code> flag on <code>Attr</code> nodes 
- * in itself is not always reliable, it is only reliable when it is set to 
- * <code>false</code> since the only case where it can be set to 
- * <code>false</code> is if the attribute was created by the implementation. 
- * The default content won't be removed if an implementation does not have 
- * any information available.How does exactly work? What's the comment about 
- * level 1 implementations?Remove "Level 1" (Telcon 16 Jan 2002).</dd>
+ * <dd>[<em>required</em>] Exposed schema-normalized values in the tree. Since this parameter
+ * requires to have schema information, the "validate" parameter will also
+ * be set to <code>true</code>. Having this parameter activated when
+ * "validate" is <code>false</code> has no effect and no
+ * schema-normalization will happen.
+ * <p ><b>Note:</b>  Since the document contains the result of the XML 1.0
+ * processing, this parameter does not apply to attribute value
+ * normalization as defined in section 3.3.3 of [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>] and is only
+ * meant for schema languages other than Document Type Definition (DTD). </dd>
  * <dt>
  * <code>false</code></dt>
- * <dd>[required]Keep all attributes and all content.</dd>
+ * <dd>[<em>required</em>] (<em>default</em>) Do not perform schema normalization on the tree. </dd>
  * </dl></dd>
- * <dt>
- * <code>"entities"</code></dt>
+ * <dt><code>"entities"</code></dt>
  * <dd>
  * <dl>
- * <dt><code>true</code></dt>
- * <dd>[required]Keep 
- * <code>EntityReference</code> and <code>Entity</code> nodes in the 
- * document.How does that interact with expand-entity-references? ALH 
- * suggests consolidating the two to a single feature called 
- * "entity-references" that is used both for load and save.Consolidate both 
- * features into a single feature called 'entities'. (Telcon 27 Jan 2002).</dd>
  * <dt>
- * <code>false</code></dt>
- * <dd>[required] (default)Remove all 
- * <code>EntityReference</code> and <code>Entity</code> nodes from the 
- * document, putting the entity expansions directly in their place. 
- * <code>Text</code> nodes are into "normal" form. Only 
- * <code>EntityReference</code> nodes to non-defined entities are kept in 
- * the document.</dd>
- * </dl></dd>
- * <dt><code>"infoset"</code></dt>
+ * <code>true</code></dt>
+ * <dd>[<em>required</em>] (<em>default</em>)Keep <code>EntityReference</code> and <code>Entity</code> nodes in the
+ * document.</dd>
+ * <dt><code>false</code></dt>
+ * <dd>[<em>required</em>] Remove all <code>EntityReference</code> and <code>Entity</code> nodes
+ * from the document, putting the entity expansions directly in their place.
+ * <code>Text</code> nodes are normalized, as defined in
+ * <code>Node.normalize</code>. Only <code>EntityReference</code> nodes to
+ * non-defined entities are kept in the document, with their associated
+ * <code>Entity</code> nodes if any. </dd>
+ * </dl></dd>
+ * <dt><code>"error-handler"</code></dt>
+ * <dd>[<em>required</em>] Contains a <code>DOMErrorHandler</code> object. If an error is
+ * encountered in the document, the implementation will call back the
+ * <code>DOMErrorHandler</code> registered using this parameter.  When
+ * called, <code>DOMError.relatedData</code> will contain the closest node
+ * to where the error occurred. If the implementation is unable to determine
+ * the node where the error occurs, <code>DOMError.relatedData</code> will
+ * contain the <code>Document</code> node. Mutations to the document from
+ * within an error handler will result in implementation dependent behavior. </dd>
+ * <dt>
+ * <code>"infoset"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[required]Only keep 
- * in the document the information defined in the XML Information Set [<a href='http://www.w3.org/TR/2001/REC-xml-infoset-20011024/'>XML Information set</a>].This 
- * forces the following features to <code>false</code>: 
- * <code>namespace-declarations</code>, <code>validate-if-schema</code>, 
- * <code>entities</code>, <code>datatype-normalization</code>, 
- * <code>cdata-sections</code>.This forces the following features to 
- * <code>true</code>: <code>whitespace-in-element-content</code>, 
- * <code>comments</code>, <code>namespaces</code>.Other features are not 
- * changed unless explicity specified in the description of the features. 
- * Note that querying this feature with <code>getFeature</code> returns 
- * <code>true</code> only if the individual features specified above are 
- * appropriately set.Name doesn't work well here. ALH suggests renaming this 
- * to limit-to-infoset or match-infoset, something like that.Renamed 
- * 'infoset' (Telcon 27 Jan 2002).</dd>
- * <dt><code>false</code></dt>
- * <dd>Setting 
- * <code>infoset</code> to <code>false</code> has no effect.Shouldn't we 
- * change this to setting the relevant options back to their default value?
- * No, this is more like a convenience function, it's better to keep it 
- * simple. (F2F 28 Feb 2002).</dd>
+ * <dd>[<em>required</em>]Keep in the document the information defined in the XML Information Set [<a href='http://www.w3.org/TR/2001/REC-xml-infoset-20011024/'>XML Information set</a>]
+ * .This forces the following parameters to <code>false</code>: "
+ * validate-if-schema", "entities", "datatype-normalization", "cdata-sections
+ * ".This forces the following parameters to <code>true</code>: "
+ * namespace-declarations", "well-formed", "whitespace-in-element-content", "
+ * comments", "namespaces".Other parameters are not changed unless
+ * explicitly specified in the description of the parameters. Note that
+ * querying this parameter with <code>getParameter</code> returns
+ * <code>true</code> only if the individual parameters specified above are
+ * appropriately set.</dd>
+ * <dt><code>false</code></dt>
+ * <dd>Setting <code>infoset</code> to
+ * <code>false</code> has no effect.</dd>
  * </dl></dd>
  * <dt><code>"namespaces"</code></dt>
  * <dd>
  * <dl>
- * <dt><code>true</code></dt>
- * <dd>[
- * required] (default) Perform the namespace processing as defined in [<a href='http://www.w3.org/TR/1999/REC-xml-names-19990114/'>XML Namespaces</a>]. </dd>
  * <dt>
- * <code>false</code></dt>
- * <dd>[optional] Do not perform the namespace processing. </dd>
+ * <code>true</code></dt>
+ * <dd>[<em>required</em>] (<em>default</em>) Perform the namespace processing as defined in . </dd>
+ * <dt><code>false</code></dt>
+ * <dd>[<em>optional</em>] Do not perform the namespace processing. </dd>
  * </dl></dd>
  * <dt>
  * <code>"namespace-declarations"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[required] (default)
- * Include namespace declaration attributes, specified or defaulted from the 
- * schema or the DTD, in the document. See also the section Declaring 
- * Namespaces in [<a href='http://www.w3.org/TR/1999/REC-xml-names-19990114/'>XML Namespaces</a>].</dd>
- * <dt><code>false</code></dt>
- * <dd>[required]Discard all namespace 
- * declaration attributes. The Namespace prefixes are retained even if this 
- * feature is set to <code>false</code>.</dd>
+ * <dd>[<em>required</em>] (<em>default</em>) Include namespace declaration attributes, specified or defaulted from
+ * the schema, in the document. See also the sections "Declaring Namespaces"
+ * in [<a href='http://www.w3.org/TR/1999/REC-xml-names-19990114/'>XML Namespaces</a>]
+ *  and [<a href='http://www.w3.org/TR/2002/CR-xml-names11-20021218/'>XML Namespaces 1.1</a>]
+ * .</dd>
+ * <dt><code>false</code></dt>
+ * <dd>[<em>required</em>]Discard all namespace declaration attributes. The namespace prefixes (
+ * <code>Node.prefix</code>) are retained even if this parameter is set to
+ * <code>false</code>.</dd>
  * </dl></dd>
  * <dt><code>"normalize-characters"</code></dt>
  * <dd>
  * <dl>
+ * <dt><code>true</code></dt>
+ * <dd>[<em>optional</em>] Fully normalize the characters in the document according to the rules
+ * defined in [<a href='http://www.w3.org/TR/2002/WD-charmod-20020430'>CharModel</a>]
+ * supplemented by the definitions of relevant constructs from <a href='http://www.w3.org/TR/2002/CR-xml11-20021015/#sec2.13'>Section 2.13</a> of [<a href='http://www.w3.org/TR/2002/CR-xml11-20021015/'>XML 1.1</a>]. </dd>
  * <dt>
- * <code>true</code></dt>
- * <dd>[optional]Perform the W3C Text Normalization of the 
- * characters [<a href='http://www.w3.org/TR/2002/WD-charmod-20020430'>CharModel</a>] in the document. </dd>
- * <dt><code>false</code></dt>
- * <dd>[required] (default)Do not 
- * perform character normalization.</dd>
+ * <code>false</code></dt>
+ * <dd>[<em>required</em>] (<em>default</em>)Do not perform character normalization.</dd>
  * </dl></dd>
+ * <dt><code>"schema-location"</code></dt>
+ * <dd>[<em>optional</em>] Represent a <code>DOMString</code> object containing a list of URIs,
+ * separated by whitespaces (characters matching the <a href='http://www.w3.org/TR/2000/REC-xml-20001006#NT-S'>nonterminal
+ * production S</a> defined in section 2.3 [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>]), that
+ * represents the schemas against which validation should occur, i.e. the
+ * current schema. The types of schemas referenced in this list must match
+ * the type specified with <code>schema-type</code>, otherwise the behavior
+ * of an implementation is undefined.  The schemas specified using this
+ * property take precedence to the schema information specified in the
+ * document itself. For namespace aware schema, if a schema specified using
+ * this property and a schema specified in the document instance (i.e. using
+ * the <code>schemaLocation</code> attribute) in a schema document (i.e.
+ * using schema <code>import</code> mechanisms) share the same
+ * <code>targetNamespace</code>, the schema specified by the user using this
+ * property will be used. If two schemas specified using this property share
+ * the same <code>targetNamespace</code> or have no namespace, the behavior
+ * is implementation dependent.  If no location has been provided, this
+ * parameter is <code>null</code>.
+ * <p ><b>Note:</b>  It is illegal to set the <code>"schema-location"</code>
+ * parameter if the "schema-type" parameter value is not set. It is strongly
+ * recommended that <code>Document.documentURI</code> will be set so that an
+ * implementation can successfully resolve any external entities referenced. </dd>
+ * <dt>
+ * <code>"schema-type"</code></dt>
+ * <dd>[<em>optional</em>] Represent a <code>DOMString</code> object containing an absolute URI
+ * and representing the type of the schema language used to validate a
+ * document against. Note that no lexical checking is done on the absolute
+ * URI.  If this parameter is not set, a default value may be provided by
+ * the implementation, based on the schema languages supported and on the
+ * schema language used at load time. If no value is provided, this
+ * parameter is <code>null</code>.
+ * <p ><b>Note:</b>  For XML Schema [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>]
+ * , applications must use the value
+ * <code>"http://www.w3.org/2001/XMLSchema"</code>. For XML DTD [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>],
+ * applications must use the value
+ * <code>"http://www.w3.org/TR/REC-xml"</code>. Other schema languages are
+ * outside the scope of the W3C and therefore should recommend an absolute
+ * URI in order to use this method. </dd>
  * <dt><code>"split-cdata-sections"</code></dt>
  * <dd>
  * <dl>
  * <dt>
  * <code>true</code></dt>
- * <dd>[required] (default)Split CDATA sections containing the 
- * CDATA section termination marker ']]&gt;'. When a CDATA section is split 
- * a warning is issued.</dd>
- * <dt><code>false</code></dt>
- * <dd>[required]Signal an error if a 
- * <code>CDATASection</code> contains an unrepresentable character.</dd>
- * </dl></dd>
+ * <dd>[<em>required</em>] (<em>default</em>)Split CDATA sections containing the CDATA section termination marker
+ * ']]&gt;'. When a CDATA section is split a warning is issued with a
+ * <code>DOMError.type</code> equals to
+ * <code>"cdata-sections-splitted"</code> and
+ * <code>DOMError.relatedData</code> equals to the first
+ * <code>CDATASection</code> node in document order resulting from the split.</dd>
  * <dt>
- * <code>"validate"</code></dt>
+ * <code>false</code></dt>
+ * <dd>[<em>required</em>]Signal an error if a <code>CDATASection</code> contains an
+ * unrepresentable character.</dd>
+ * </dl></dd>
+ * <dt><code>"validate"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[optional] Require the validation 
- * against a schema (i.e. XML schema, DTD, any other type or representation 
- * of schema) of the document as it is being normalized as defined by [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>]. If 
+ * <dd>[<em>optional</em>] Require the validation against a schema (i.e. XML schema, DTD, any
+ * other type or representation of schema) of the document as it is being
+ * normalized as defined by [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>]. If
  * validation errors are found, or no schema was found, the error handler is 
- * notified. Note also that no datatype normalization (i.e. non-XML 1.0 
- * normalization) is done according to the schema used unless the feature 
- * <code>datatype-normalization</code> is <code>true</code>.  
- * <code>validate-if-schema</code> and <code>validate</code> are mutually 
+ * notified. Schema-normalized values will not be exposed according to the
+ * schema in used unless the parameter "datatype-normalization" is
+ * <code>true</code>.  This parameter will reevaluate:
+ * <ul>
+ * <li> Attribute nodes with
+ * <code>Attr.specified</code> equals to <code>false</code>, as specified in
+ * the description of the <code>Attr</code> interface;
+ * </li>
+ * <li> The result of the
+ * method <code>Text.isWhitespaceInElementContent()</code> for all
+ * <code>Text</code> nodes;
+ * </li>
+ * <li> The result of the method
+ * <code>Attr.isId()</code> for all <code>Attr</code> nodes;
+ * </li>
+ * <li> The attributes
+ * <code>Element.schemaTypeInfo</code> and <code>Attr.schemaTypeInfo</code>.
+ * </li>
+ * </ul>
+ * <p ><b>Note:</b>  "validate-if-schema" and "validate" are mutually
  * exclusive, setting one of them to <code>true</code> will set the other 
- * one to <code>false</code>. </dd>
+ * one to <code>false</code>. Applications should also consider setting the
+ * parameter "well-formed" to <code>true</code>, which is the default for
+ * that option, when validating the document. </dd>
  * <dt><code>false</code></dt>
- * <dd>[required] (default) Only 
- * XML 1.0 non-validating processing must be done. Note that validation 
- * might still happen if <code>validate-if-schema</code> is <code>true</code>
- * . </dd>
+ * <dd>[<em>required</em>] (<em>default</em>) Do not accomplish schema processing, including the internal subset
+ * processing. Note that validation might still happen if "
+ * "validate-if-schema" is <code>true</code>. </dd>
  * </dl></dd>
- * <dt><code>"validate-if-schema"</code></dt>
+ * <dt>
+ * <code>"validate-if-schema"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[optional]Enable 
- * validation only if a declaration for the document element can be found 
- * (independently of where it is found, i.e. XML schema, DTD, or any other 
- * type or representation of schema). If validation errors are found, the 
- * error handler is notified. Note also that no datatype normalization (i.e. 
- * non-XML 1.0 normalization) is done according to the schema used unless 
- * the feature <code>datatype-normalization</code> is <code>true</code>. 
- * <code>validate-if-schema</code> and <code>validate</code> are mutually 
+ * <dd>[<em>optional</em>]Enable validation only if a declaration for the document element can be
+ * found in a schema (independently of where it is found, i.e. XML schema,
+ * DTD, or any other type or representation of schema). If validation is
+ * enabled, this parameter has the same behavior as the parameter "validate"
+ * set to <code>true</code>.
+ * <p ><b>Note:</b>  "validate-if-schema" and "validate" are mutually
  * exclusive, setting one of them to <code>true</code> will set the other 
  * one to <code>false</code>. </dd>
  * <dt><code>false</code></dt>
- * <dd>[required] (default)No 
- * validation should be performed if the document has a schema. Note that 
- * validation must still happen if <code>validate</code> is <code>true</code>
- * . </dd>
+ * <dd>[<em>required</em>] (<em>default</em>) No schema processing should be performed if the document has a schema,
+ * including internal subset processing. Note that validation must still
+ * happen if "validate" is <code>true</code>. </dd>
  * </dl></dd>
- * <dt><code>"whitespace-in-element-content"</code></dt>
+ * <dt><code>"well-formed"</code></dt>
+ * <dd>
+ * <dl>
+ * <dt>
+ * <code>true</code></dt>
+ * <dd>[<em>required</em>] (<em>default</em>) Check if all nodes are XML well formed according to the XML version in
+ * use in <code>Document.xmlVersion</code>:
+ * <ul>
+ * <li> check if the attribute
+ * <code>Node.nodeName</code> contains invalid characters according to its
+ * node type and generate a <code>DOMError</code> of type
+ * <code>"wf-invalid-character-in-node-name"</code> if necessary;
+ * </li>
+ * <li> check if
+ * the text content inside <code>Attr</code>, <code>Element</code>,
+ * <code>Comment</code>, <code>Text</code>, <code>CDATASection</code> nodes
+ * for invalid characters and generate a <code>DOMError</code> of type
+ * <code>"wf-invalid-character"</code> if necessary;
+ * </li>
+ * <li> check if the data
+ * inside <code>ProcessingInstruction</code> nodes for invalid characters
+ * and generate a <code>DOMError</code> of type
+ * <code>"wf-invalid-character"</code> if necessary;
+ * </li>
+ * </ul></dd>
+ * <dt><code>false</code></dt>
+ * <dd>[<em>optional</em>] Do not check for XML well-formedness. </dd>
+ * </dl></dd>
+ * <dt>
+ * <code>"whitespace-in-element-content"</code></dt>
  * <dd>
  * <dl>
  * <dt><code>true</code></dt>
- * <dd>[required] 
- * (default)Keep all white spaces in the document. How does this feature 
- * interact with <code>"validate"</code> and 
- * <code>Text.isWhitespaceInElementContent</code>. issue no longer relevant 
- * (f2f october 2002).</dd>
- * <dt><code>false</code></dt>
- * <dd>[optional]Discard white space in 
- * element content while normalizing. The implementation is expected to use 
- * the <code>isWhitespaceInElementContent</code> flag on <code>Text</code> 
- * nodes to determine if a text node should be written out or not.</dd>
+ * <dd>[<em>required</em>] (<em>default</em>)Keep all whitespaces in the document.</dd>
+ * <dt><code>false</code></dt>
+ * <dd>[<em>optional</em>] Discard all <code>Text</code> nodes that contain whitespaces in element
+ * content. The implementation is expected to use the method
+ * <code>Text.isWhitespaceInElementContent</code> to determine if a
+ * <code>Text</code> node should be discarded or not.</dd>
  * </dl></dd>
  * </dl>
- * <p> The resolutions of entities is done using <code>Document.baseURI</code>
- * . However, when the features "LS-Load" or "LS-Save" defined in [<a href='http://www.w3.org/TR/DOM-Level-3-LS'>DOM Level 3 Load and Save</a>] are 
- * supported by the DOM implementation, the parameter 
- * <code>"entity-resolver"</code> can also be used on 
- * <code>DOMConfiguration</code> objects attached to <code>Document</code> 
- * nodes. If this parameter is set, <code>Document.normalizeDocument</code> 
- * will invoke the entity resolver instead of using 
- * <code>Document.baseURI</code>. 
- * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20021022'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * <p> The resolution of the system identifiers associated with entities is
+ * done using <code>Document.documentURI</code>. However, when the feature
+ * "LS" defined in [<a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-LS-20030226'>DOM Level 3 Load and Save</a>]
+ *  is supported by the DOM implementation, the parameter
+ * "resource-resolver" can also be used on <code>DOMConfiguration</code>
+ * objects attached to <code>Document</code> nodes. If this parameter is
+ * set, <code>Document.normalizeDocument()</code> will invoke the entity
+ * resolver instead of using <code>Document.documentURI</code>.
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
  * @since DOM Level 3
  */
 public interface DOMConfiguration {
@@ -336,14 +357,14 @@
      *   unset the parameter. While the type of the value parameter is 
      *   defined as <code>DOMUserData</code>, the object type must match the 
      *   type defined by the definition of the parameter. For example, if 
-     *   the parameter is <code>"error-handler"</code>, the value must be of 
-     *   type <code>DOMErrorHandler</code>.  Should we allow implementations 
-     *   to raise exception if the type does not match? INVALID_ACCESS_ERR 
-     *   seems the closest exception code... 
+     *   the parameter is "error-handler", the value must be of type
+     *   <code>DOMErrorHandler</code>.
      * @exception DOMException
-     *    NOT_SUPPORTED_ERR: Raised when the parameter name is recognized but 
-     *   the requested value cannot be set. 
-     *   <br> NOT_FOUND_ERR: Raised when the parameter name is not recognized. 
+     *    NOT_FOUND_ERR: Raised when the parameter name is not recognized.
+     *   <br> NOT_SUPPORTED_ERR: Raised when the parameter name is recognized
+     *   but the requested value cannot be set.
+     *   <br> TYPE_MISMATCH_ERR: Raised if the value type for this parameter
+     *   name is incompatible with the expected value type.
      */
     public void setParameter(String name, 
                              Object value)
@@ -354,9 +375,7 @@
      * @param name  The name of the parameter. 
      * @return  The current object associated with the specified parameter or 
      *   <code>null</code> if no object has been associated or if the 
-     *   parameter is not supported.  "by a DOM application" prevents a DOM 
-     *   implementation to return its default behavior (such as the default 
-     *   "schema-type") if any. 
+     *   parameter is not supported.
      * @exception DOMException
      *    NOT_FOUND_ERR: Raised when the parameter name is not recognized. 
      */
Index: xml-xerces/java/src/org/apache/xerces/dom3/DOMError.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/DOMError.java,v
retrieving revision 1.3
diff -u -w -r1.3 DOMError.java
--- xml-xerces/java/src/org/apache/xerces/dom3/DOMError.java	17 Jan 2003 22:40:54 -0000	1.3
+++ xml-xerces/java/src/org/apache/xerces/dom3/DOMError.java	29 Jul 2003 12:47:31 -0000
@@ -1,28 +1,24 @@
 /*
- * Copyright (c) 2002 World Wide Web Consortium,
- * (Massachusetts Institute of Technology, Institut National de
- * Recherche en Informatique et en Automatique, Keio University). All
- * Rights Reserved. This program is distributed under the W3C's Software
- * Intellectual Property License. This program is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
- * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.
- * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
+ * Copyright (c) 2003 World Wide Web Consortium,
+ *
+ * (Massachusetts Institute of Technology, European Research Consortium for
+ * Informatics and Mathematics, Keio University). All Rights Reserved. This
+ * work is distributed under the W3C(r) Software License [1] in the hope that
+ * it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * [1] http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
 package org.apache.xerces.dom3;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- * <p>
  * <code>DOMError</code> is an interface that describes an error.
- * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20020409'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * @since DOM Level 3
  */
 public interface DOMError {
+    // ErrorSeverity
     /**
      * The severity of the error described by the <code>DOMError</code> is 
      * warning
@@ -38,6 +34,7 @@
      * fatal error
      */
     public static final short SEVERITY_FATAL_ERROR      = 2;
+
     /**
      * The severity of the error, either <code>SEVERITY_WARNING</code>, 
      * <code>SEVERITY_ERROR</code>, or <code>SEVERITY_FATAL_ERROR</code>.
@@ -45,41 +42,38 @@
     public short getSeverity();
 
     /**
-     * An implementation specific string describing the error that occured.
+     * An implementation specific string describing the error that occurred.
      */
     public String getMessage();
 
     /**
-     * The related platform dependent exception if any.exception is a reserved 
-     * word, we need to rename it.Change to "relatedException". (F2F 26 Sep 
-     * 2001)
+     *  A <code>DOMString</code> indicating which related data is expected in
+     * <code>relatedData</code>. Users should refer to the specification of
+     * the error in order to find its <code>DOMString</code> type and
+     * <code>relatedData</code> definitions if any.
+     * <p ><b>Note:</b>  As an example,
+     * <code>Document.normalizeDocument()</code> does generate warnings when
+     * the "split-cdata-sections" parameter is in use. Therefore, the method
+     * generates a <code>SEVERITY_WARNING</code> with <code>type</code>
+     * <code>"cdata-section-splitted"</code> and the first
+     * <code>CDATASection</code> node in document order resulting from the
+     * split is returned by the <code>relatedData</code> attribute.
      */
-    public Object getRelatedException();
+    public String getType();
 
     /**
-     * The location of the error.
+     * The related platform dependent exception if any.
      */
-    public DOMLocator getLocation();
+    public Object getRelatedException();
     
         /**
-     *  The related <code>Error.type</code> dependent data if any. 
+     *  The related <code>DOMError.type</code> dependent data if any.
      */
-
     public Object getRelatedData();
+
         /**
-     *  A <code>DOMString</code> indicating which related data is expected in 
-     * <code>relatedData</code>. Users should refer to the specification of 
-     * the error in order to find its <code>DOMString</code> type and 
-     * <code>relatedData</code> definitions if any.  As an example, [<a href='http://www.w3.org/TR/DOM-Level-3-LS'>DOM Level 3 Load and Save</a>] does 
-     * not keep the [baseURI] property defined on a Processing Instruction 
-     * information item. Therefore, the <code>DOMBuilder</code> generates a 
-     * <code>SEVERITY_WARNING</code> with <code>type</code> 
-     * <code>"infoset-baseURI"</code> and the lost [baseURI] property 
-     * represented as a <code>DOMString</code> in the 
-     * <code>relatedData</code> attribute. 
+     * The location of the error.
      */
-
-    public String getType();
-
+    public DOMLocator getLocation();
 
 }
Index: xml-xerces/java/src/org/apache/xerces/dom3/DOMErrorHandler.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/DOMErrorHandler.java,v
retrieving revision 1.2
diff -u -w -r1.2 DOMErrorHandler.java
--- xml-xerces/java/src/org/apache/xerces/dom3/DOMErrorHandler.java	23 Aug 2002 20:14:39 -0000	1.2
+++ xml-xerces/java/src/org/apache/xerces/dom3/DOMErrorHandler.java	29 Jul 2003 12:47:31 -0000
@@ -1,44 +1,42 @@
 /*
- * Copyright (c) 2002 World Wide Web Consortium,
- * (Massachusetts Institute of Technology, Institut National de
- * Recherche en Informatique et en Automatique, Keio University). All
- * Rights Reserved. This program is distributed under the W3C's Software
- * Intellectual Property License. This program is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
- * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.
- * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
+ * Copyright (c) 2003 World Wide Web Consortium,
+ *
+ * (Massachusetts Institute of Technology, European Research Consortium for
+ * Informatics and Mathematics, Keio University). All Rights Reserved. This
+ * work is distributed under the W3C(r) Software License [1] in the hope that
+ * it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * [1] http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
 package org.apache.xerces.dom3;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- * <p>
  * <code>DOMErrorHandler</code> is a callback interface that the DOM 
  * implementation can call when reporting errors that happens while 
  * processing XML data, or when doing some other processing (e.g. validating 
- * a document).
+ * a document). A <code>DOMErrorHandler</code> object can be attached to a
+ * <code>Document</code> using the "error-handler" on the
+ * <code>DOMConfiguration</code> interface. If more than one error needs to
+ * be reported during an operation, the sequence and numbers of the errors
+ * passed to the error handler are implementation dependent.
  * <p>The application that is using the DOM implementation is expected to 
- * implement this interface.How does one register an error handler in the 
- * core? Passed as an argument to super-duper-normalize or registered on the 
- * DOMImplementation?Document interface has an attribute errorHandler.
- * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20020409'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * implement this interface.
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * @since DOM Level 3
  */
 public interface DOMErrorHandler {
     /**
-     * This method is called on the error handler when an error occures.
-     * @param error The error object that describes the error, this object 
+     * This method is called on the error handler when an error occurs.
+     * @param error  The error object that describes the error. This object
      *   may be reused by the DOM implementation across multiple calls to 
-     *   the handleEvent method.
-     * @return If the handleError method returns <code>true</code> the DOM 
-     *   implementation should continue as if the error didn't happen when 
-     *   possible, if the method returns <code>false</code> then the DOM 
-     *   implementation should stop the current processing when possible.
+     *   the <code>handleError</code> method.
+     * @return  If the <code>handleError</code> method returns
+     *   <code>true</code>, the DOM implementation should continue as if the
+     *   error didn't happen when possible, if the method returns
+     *   <code>false</code> then the DOM implementation should stop the
+     *   current processing when possible.
      */
     public boolean handleError(DOMError error);
 
Index: xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationList.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationList.java,v
retrieving revision 1.1
diff -u -w -r1.1 DOMImplementationList.java
--- xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationList.java	20 Mar 2003 00:38:30 -0000	1.1
+++ xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationList.java	29 Jul 2003 12:47:31 -0000
@@ -20,7 +20,7 @@
  * constraining how this collection is implemented. The items in the 
  * <code>DOMImplementationList</code> are accessible via an integral index, 
  * starting from 0. 
- * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030226'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
  * @since DOM Level 3
  */
 public interface DOMImplementationList {
Index: xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationSource.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationSource.java,v
retrieving revision 1.3
diff -u -w -r1.3 DOMImplementationSource.java
--- xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationSource.java	20 Mar 2003 00:38:30 -0000	1.3
+++ xml-xerces/java/src/org/apache/xerces/dom3/DOMImplementationSource.java	29 Jul 2003 12:47:31 -0000
@@ -1,13 +1,13 @@
 /*
- * Copyright (c) 2002 World Wide Web Consortium,
- * (Massachusetts Institute of Technology, Institut National de
- * Recherche en Informatique et en Automatique, Keio University). All
- * Rights Reserved. This program is distributed under the W3C's Software
- * Intellectual Property License. This program is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
- * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.
- * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
+ * Copyright (c) 2003 World Wide Web Consortium,
+ *
+ * (Massachusetts Institute of Technology, European Research Consortium for
+ * Informatics and Mathematics, Keio University). All Rights Reserved. This
+ * work is distributed under the W3C(r) Software License [1] in the hope that
+ * it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * [1] http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
 package org.apache.xerces.dom3;
@@ -15,42 +15,44 @@
 import org.w3c.dom.DOMImplementation;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- * <p>
  * This interface permits a DOM implementer to supply one or more 
- * implementations, based upon requested features. Each implemented 
- * <code>DOMImplementationSource</code> object is listed in the 
- * binding-specific list of available sources so that its 
+ * implementations, based upon requested features and versions, as specified
+ * in . Each implemented <code>DOMImplementationSource</code> object is
+ * listed in the binding-specific list of available sources so that its
  * <code>DOMImplementation</code> objects are made available.
- * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20020409'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * @since DOM Level 3
  */
 public interface DOMImplementationSource {
     /**
-     * A method to request a DOM implementation.
-     * @param features A string that specifies which features are required. 
-     *   This is a space separated list in which each feature is specified 
-     *   by its name optionally followed by a space and a version number. 
-     *   This is something like: "XML 1.0 Traversal Events 2.0"
-     * @return An implementation that has the desired features, or 
-     *   <code>null</code> if this source has none.
+     *  A method to request the first DOM implementation that support the
+     * specified features.
+     * @param features  A string that specifies which features and versions
+     *   are required. This is a space separated list in which each feature
+     *   is specified by its name optionally followed by a space and a
+     *   version number.  As an example, the string
+     *   <code>"XML 3.0 Traversal +Events 2.0"</code> will request a DOM
+     *   implementation that supports the module "XML" for its 3.0 version,
+     *   a module that support of the "Traversal" module for any version,
+     *   and the module "Events" for its 2.0 version. The module "Events"
+     *   must be accessible using the method <code>Node.getFeature()</code>
+     *   and <code>DOMImplementation.getFeature()</code>.
+     * @return The first DOM implementation that support the desired
+     *   features, or <code>null</code> if this source has none.
      */
     public DOMImplementation getDOMImplementation(String features);
     
     /**
      * A method to request a list of DOM implementations that support the 
-     * specified features.
-     * @param features A string that specifies which features are required. 
-     *   This is a space separated list in which each feature is specified 
-     *   by its name optionally followed by a space and a version number. 
-     *   This is something like: "XML 1.0 Traversal Events 2.0"
+     * specified features and versions, as specified in .
+     * @param features A string that specifies which features and versions
+     *   are required. This is a space separated list in which each feature
+     *   is specified by its name optionally followed by a space and a
+     *   version number. This is something like: "XML 3.0 Traversal +Events
+     *   2.0"
      * @return A list of DOM implementations that support the desired 
      *   features.
      */
     public DOMImplementationList getDOMImplementations(String features);
-
 
 }
Index: xml-xerces/java/src/org/apache/xerces/dom3/DOMLocator.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/DOMLocator.java,v
retrieving revision 1.3
diff -u -w -r1.3 DOMLocator.java
--- xml-xerces/java/src/org/apache/xerces/dom3/DOMLocator.java	20 Mar 2003 00:38:30 -0000	1.3
+++ xml-xerces/java/src/org/apache/xerces/dom3/DOMLocator.java	29 Jul 2003 12:47:31 -0000
@@ -1,13 +1,13 @@
 /*
- * Copyright (c) 2002 World Wide Web Consortium,
- * (Massachusetts Institute of Technology, Institut National de
- * Recherche en Informatique et en Automatique, Keio University). All
- * Rights Reserved. This program is distributed under the W3C's Software
- * Intellectual Property License. This program is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
- * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.
- * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
+ * Copyright (c) 2003 World Wide Web Consortium,
+ *
+ * (Massachusetts Institute of Technology, European Research Consortium for
+ * Informatics and Mathematics, Keio University). All Rights Reserved. This
+ * work is distributed under the W3C(r) Software License [1] in the hope that
+ * it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * [1] http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
 package org.apache.xerces.dom3;
@@ -15,45 +15,42 @@
 import org.w3c.dom.Node;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- * <p>
  * <code>DOMLocator</code> is an interface that describes a location (e.g. 
- * where an error occured).
- * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20020409'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * where an error occurred).
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * @since DOM Level 3
  */
 public interface DOMLocator {
     /**
-     * The line number where the error occured, or -1 if there is no line 
-     * number available.
+     * The line number this locator is pointing to, or <code>-1</code> if
+     * there is no column number available.
      */
     public int getLineNumber();
 
     /**
-     * The column number where the error occured, or -1 if there is no column 
-     * number available.
+     * The column number this locator is pointing to, or <code>-1</code> if
+     * there is no column number available.
      */
     public int getColumnNumber();
 
     /**
-     * The byte or character offset into the input source, if we're parsing a 
-     * file or a byte stream then this will be the byte offset into that 
-     * stream, but if a character media is parsed then the offset will be 
-     * the character offset. The value is <code>-1</code> if there is no 
-     * offset available.
+     * The byte or character offset into the input source this locator is
+     * pointing to. If the input source is a file or a byte stream then this
+     * is the byte offset into that stream, but if the input source is a
+     * character media then the offset is the character offset. The value is
+     * <code>-1</code> if there is no offset available.
      */
     public int getOffset();
 
     /**
-     * The node this locator is pointing to, or null if no node is available
+     * The node this locator is pointing to, or <code>null</code> if no node
+     * is available.
      */
     public Node getRelatedNode();
 
     /**
-     * The URI where the error occured, or null if there is no URI available.
+     * The URI this locator is pointing to, or <code>null</code> if no URI is
+     * available.
      */
     public String getUri();
 
Index: xml-xerces/java/src/org/apache/xerces/dom3/TypeInfo.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/TypeInfo.java,v
retrieving revision 1.1
diff -u -w -r1.1 TypeInfo.java
--- xml-xerces/java/src/org/apache/xerces/dom3/TypeInfo.java	16 Jan 2003 22:53:44 -0000	1.1
+++ xml-xerces/java/src/org/apache/xerces/dom3/TypeInfo.java	29 Jul 2003 12:47:31 -0000
@@ -1,72 +1,99 @@
 /*
- * Copyright (c) 2002 World Wide Web Consortium,
- * (Massachusetts Institute of Technology, Institut National de
- * Recherche en Informatique et en Automatique, Keio University). All
- * Rights Reserved. This program is distributed under the W3C's Software
- * Intellectual Property License. This program is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
- * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.
- * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
+ * Copyright (c) 2003 World Wide Web Consortium,
+ *
+ * (Massachusetts Institute of Technology, European Research Consortium for
+ * Informatics and Mathematics, Keio University). All Rights Reserved. This
+ * work is distributed under the W3C(r) Software License [1] in the hope that
+ * it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * [1] http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
+
 package org.apache.xerces.dom3;
 
 /**
  *  The <code>TypeInfo</code> interface represent a type referenced from 
  * <code>Element</code> or <code>Attr</code> nodes, specified in the schemas 
  * associated with the document. The type is a pair of a namespace URI and 
- * name properties, and depends on the document's schema.  should you be 
- * able to return <code>null</code> on <code>name</code>? for anonymous 
- * type? for undeclared elements/attributes? Can schemaType be 
- * <code>null</code>? 
- * <p> If the document's schema is an XML DTD [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>], the values are computed as 
- * follows:  If this type is referenced from an <code>Attr</code> node, 
- * <code>namespace</code> is <code>null</code> and <code>name</code> 
- * represents the [attribute type] property in the [<a href='http://www.w3.org/TR/2001/REC-xml-infoset-20011024/'>XML Information set</a>]. If there is no 
- * declaration for the attribute, <code>name</code> is <code>null</code>.  
- * Unlike for XML Schema, the name contain the declared type, and does not 
- * relate to "validity".  If this type is referenced from an 
- * <code>Element</code> node, the <code>namespace</code> and 
- * <code>name</code> are <code>null</code>. 
- * <p> 
- * If the document's schema is an XML Schema [XML Schema Part 1], the
- * values are computed as follows (for definitions see Post-Schema
- * Validation infoset):
- * <p>If the [validity] property exists AND is "invalid" or "notKnown":
- * the {target namespace} and {name} properties of the declared type 
- * if available, otherwise null.
- * <p>Note: At the time of writing, the XML Schema specification does not 
- * require exposing the declared type. Thus, DOM implementations
- * might choose not to provide type information if validity is not valid.
- * <p>If the [validity] property exists and is "valid" the name and namespace
- * computed as follows:
- * <p>a) If [member type definition] exists, then expose the 
- * {target namespace} and {name} properties of the 
- * [member type definition] property;
- * <p>b) If the [member type definition namespace] and the 
- * [member type definition name] exist, then expose these properties.
- * <p>c) If the [type definition] property exists, then expose the {target
- * namespace} and {name} properties of the [type definition] property;
- * <p>d) If the [type definition namespace] and the [type definition name]
- * exist, then expose these properties.
- * 
- * <p> Note: At the time of writing, the XML Schema specification does not
- * define how to expose annonimous types. If future specifications
- * define how to expose annonimous types, DOM implementations can expose
- * annonimous types via "name" and "namespace" parameters.
- * 
- * Other schema languages are outside the scope of the 
- * W3C and therefore should define how to represent their type systems using 
+ * name properties, and depends on the document's schema.
+ * <p> If the document's schema is an XML DTD [<a href='http://www.w3.org/TR/2000/REC-xml-20001006'>XML 1.0</a>], the values
+ * are computed as follows:
+ * <ul>
+ * <li> If this type is referenced from an
+ * <code>Attr</code> node, <code>typeNamespace</code> is <code>null</code>
+ * and <code>typeName</code> represents the <b>[attribute type]</b> property in the [<a href='http://www.w3.org/TR/2001/REC-xml-infoset-20011024/'>XML Information set</a>]
+ * . If there is no declaration for the attribute, <code>typeName</code> is
+ * <code>null</code>.
+ * </li>
+ * <li> If this type is referenced from an
+ * <code>Element</code> node, the <code>typeNamespace</code> and
+ * <code>typeName</code> are <code>null</code>.
+ * </li>
+ * </ul>
+ * <p> If the document's schema is an XML Schema [<a href='http://www.w3.org/TR/2001/REC-xmlschema-1-20010502/'>XML Schema Part 1</a>]
+ * , the values are computed as follows using the post-schema-validation
+ * infoset contributions (also called PSVI contributions):
+ * <ul>
+ * <li> If the <b>[validity]</b> property exists AND is <em>"invalid"</em> or <em>"notKnown"</em>: the {target namespace} and {name} properties of the declared type if
+ * available, otherwise <code>null</code>.
+ * <p ><b>Note:</b>  At the time of writing, the XML Schema specification does
+ * not require exposing the declared type. Thus, DOM implementations might
+ * choose not to provide type information if validity is not valid.
+ * </li>
+ * <li> If the <b>[validity]</b> property exists and is <em>"valid"</em>:
+ * <ol>
+ * <li> If <b>[member type definition]</b> exists:
+ * <ol>
+ * <li>If {name} is not absent, then expose {name} and {target
+ * namespace} properties of the <b>[member type definition]</b> property;
+ * </li>
+ * <li>Otherwise, expose the namespace and local name of the
+ * corresponding anonymous type name.
+ * </li>
+ * </ol>
+ * </li>
+ * <li> If the <b>[type definition]</b> property exists:
+ * <ol>
+ * <li>If {name} is not absent, then expose {name} and {target
+ * namespace} properties of the <b>[type definition]</b> property;
+ * </li>
+ * <li>Otherwise, expose the namespace and local name of the
+ * corresponding anonymous type name.
+ * </li>
+ * </ol>
+ * </li>
+ * <li> If the <b>[member type definition anonymous]</b> exists:
+ * <ol>
+ * <li>If it is false, then expose <b>[member type definition name]</b> and <b>[member type definition namespace]</b> properties;
+ * </li>
+ * <li>Otherwise, expose the namespace and local name of the
+ * corresponding anonymous type name.
+ * </li>
+ * </ol>
+ * </li>
+ * <li> If the <b>[type definition anonymous]</b> exists:
+ * <ol>
+ * <li>If it is false, then expose <b>[type definition name]</b> and <b>[type definition namespace]</b> properties;
+ * </li>
+ * <li>Otherwise, expose the namespace and local name of the
+ * corresponding anonymous type name.
+ * </li>
+ * </ol>
+ * </li>
+ * </ol>
+ * </li>
+ * </ul>
+ * <p ><b>Note:</b>  Other schema languages are outside the scope of the W3C
+ * and therefore should define how to represent their type systems using
  * <code>TypeInfo</code>. 
- * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20021022'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
  * @since DOM Level 3
  */
 public interface TypeInfo {
     /**
      *  The name of a type declared for the associated element or attribute, 
-     * or <code>null</code> if unknown. Implementations may also use 
-     * <code>null</code> to represent XML Schema anonymous types. "name" 
-     * seems too generic and may conflict. shoud we rename it?
+     * or <code>null</code> if unknown.
      */
     public String getTypeName();
 
@@ -74,9 +101,6 @@
      *  The namespace of the type declared for the associated element or 
      * attribute or <code>null</code> if the element does not have 
      * declaration or if no namespace information is available. 
-     * Implementations may also use <code>null</code> to represent XML 
-     * Schema anonymous types. "namespace" seems too generic and may 
-     * conflict. shoud we rename it?
      */
     public String getTypeNamespace();
 
Index: xml-xerces/java/src/org/apache/xerces/dom3/UserDataHandler.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/UserDataHandler.java,v
retrieving revision 1.2
diff -u -w -r1.2 UserDataHandler.java
--- xml-xerces/java/src/org/apache/xerces/dom3/UserDataHandler.java	23 Aug 2002 20:14:39 -0000	1.2
+++ xml-xerces/java/src/org/apache/xerces/dom3/UserDataHandler.java	29 Jul 2003 12:47:31 -0000
@@ -1,31 +1,28 @@
 /*
- * Copyright (c) 2002 World Wide Web Consortium,
- * (Massachusetts Institute of Technology, Institut National de
- * Recherche en Informatique et en Automatique, Keio University). All
- * Rights Reserved. This program is distributed under the W3C's Software
- * Intellectual Property License. This program is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY; without even
- * the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.
- * See W3C License http://www.w3.org/Consortium/Legal/ for more details.
+ * Copyright (c) 2003 World Wide Web Consortium,
+ *
+ * (Massachusetts Institute of Technology, European Research Consortium for
+ * Informatics and Mathematics, Keio University). All Rights Reserved. This
+ * work is distributed under the W3C(r) Software License [1] in the hope that
+ * it will be useful, but WITHOUT ANY WARRANTY; without even the implied
+ * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * [1] http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231
  */
 
 package org.apache.xerces.dom3;
+
 import org.w3c.dom.Node;
 
 /**
- * DOM Level 3 WD Experimental:
- * The DOM Level 3 specification is at the stage 
- * of Working Draft, which represents work in 
- * progress and thus may be updated, replaced, 
- * or obsoleted by other documents at any time. 
- * <p>
- * When associating an object to a key on a node using <code>setUserData</code>
- *  the application can provide a handler that gets called when the node the 
- * object is associated to is being cloned or imported. This can be used by 
- * the application to implement various behaviors regarding the data it 
- * associates to the DOM nodes. This interface defines that handler. 
- * <p>See also the <a href='http://www.w3.org/TR/2002/WD-DOM-Level-3-Core-20020409'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * When associating an object to a key on a node using
+ * <code>Node.setUserData()</code> the application can provide a handler
+ * that gets called when the node the object is associated to is being
+ * cloned, imported, or renamed. This can be used by the application to
+ * implement various behaviors regarding the data it associates to the DOM
+ * nodes. This interface defines that handler.
+ * <p>See also the <a href='http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030609'>Document Object Model (DOM) Level 3 Core Specification</a>.
+ * @since DOM Level 3
  */
 public interface UserDataHandler {
     // OperationType
@@ -39,6 +36,9 @@
     public static final short NODE_IMPORTED             = 2;
     /**
      * The node is deleted.
+     * <p ><b>Note:</b> This may not be supported or may not be reliable in
+     * certain environments, such as Java, where the implementation has no
+     * real control over when objects are actually deleted.
      */
     public static final short NODE_DELETED              = 3;
     /**
Index: xml-xerces/java/src/org/apache/xerces/dom3/as/DOMImplementationAS.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/as/DOMImplementationAS.java,v
retrieving revision 1.3
diff -u -w -r1.3 DOMImplementationAS.java
--- xml-xerces/java/src/org/apache/xerces/dom3/as/DOMImplementationAS.java	24 Mar 2003 20:27:12 -0000	1.3
+++ xml-xerces/java/src/org/apache/xerces/dom3/as/DOMImplementationAS.java	29 Jul 2003 12:47:32 -0000
@@ -34,7 +34,7 @@
 
     /**
      * Creates an <code>DOMASBuilder</code>.Do we need the method since we 
-     * already have <code>DOMImplementationLS.createDOMBuilder</code>?
+     * already have <code>DOMImplementationLS.createDOMParser</code>?
      * @return a DOMASBuilder
      */
     public DOMASBuilder createDOMASBuilder();
Index: xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationListImpl.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationListImpl.java,v
retrieving revision 1.2
diff -u -w -r1.2 DOMImplementationListImpl.java
--- xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationListImpl.java	10 Jun 2003 18:09:39 -0000	1.2
+++ xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationListImpl.java	29 Jul 2003 12:47:32 -0000
@@ -21,7 +21,7 @@
 
 import java.util.Vector;
 
-import org.apache.xerces.dom3.DOMImplementationList;
+import org.w3c.dom.DOMImplementationList;
 import org.w3c.dom.DOMImplementation;
 
 public class DOMImplementationListImpl
@@ -72,4 +72,3 @@
         sources.add(domImpl);
     }
 }
-  
\ No newline at end of file
Index: xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationRegistry.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationRegistry.java,v
retrieving revision 1.2
diff -u -w -r1.2 DOMImplementationRegistry.java
--- xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationRegistry.java	10 Jun 2003 18:09:39 -0000	1.2
+++ xml-xerces/java/src/org/apache/xerces/dom3/bootstrap/DOMImplementationRegistry.java	29 Jul 2003 12:47:32 -0000
@@ -47,8 +47,8 @@
 import java.util.Enumeration;
 import java.util.Hashtable;
 
-import org.apache.xerces.dom3.DOMImplementationSource;
-import org.apache.xerces.dom3.DOMImplementationList;
+import org.w3c.dom.DOMImplementationSource;
+import org.w3c.dom.DOMImplementationList;
 import org.w3c.dom.DOMImplementation;
 
 public class DOMImplementationRegistry { 
@@ -208,4 +208,3 @@
         }
     }
 }
-  
\ No newline at end of file

Index: xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASBuilder.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASBuilder.java,v
retrieving revision 1.3
diff -u -w -r1.3 DOMASBuilder.java
--- xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASBuilder.java	24 Mar 2003 20:27:12 -0000	1.3
+++ xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASBuilder.java	29 Jul 2003 12:47:32 -0000
@@ -12,8 +12,8 @@
 
 package org.apache.xerces.dom3.as;
 
-import org.w3c.dom.ls.DOMInputSource;
-import org.w3c.dom.ls.DOMBuilder;
+import org.w3c.dom.ls.DOMInput;
+import org.w3c.dom.ls.DOMParser;
 
 /**
  * @deprecated
@@ -23,9 +23,9 @@
  * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-ASLS-20011025'>Document Object Model (DOM) Level 3 Abstract Schemas and Load
 and Save Specification</a>.
  */
-public interface DOMASBuilder extends DOMBuilder {
+public interface DOMASBuilder extends DOMParser {
     /**
      *  Associate an <code>ASModel</code> with a <code>DOMBuilder</code>. This 
      * <code>ASModel</code> will be used by the "
      * <code>validate-if-schema</code>" and "
      * <code>datatype-normalization</code>" options during the load of a new 
@@ -33,7 +33,7 @@
      */
     public ASModel getAbstractSchema();
     /**
      *  Associate an <code>ASModel</code> with a <code>DOMBuilder</code>. This 
      * <code>ASModel</code> will be used by the "
      * <code>validate-if-schema</code>" and "
      * <code>datatype-normalization</code>" options during the load of a new 
@@ -68,8 +68,8 @@
 
     /**
      * Parse a Abstract Schema from a location identified by an 
-     * <code>DOMInputSource</code>.
-     * @param is The <code>DOMInputSource</code> from which the source 
+     * <code>DOMInput</code>.
+     * @param is The <code>DOMInput</code> from which the source
      *   Abstract Schema is to be read. 
      * @return The newly created <code>ASModel</code>.
      * @exception DOMASException
@@ -90,7 +90,7 @@
      *   system error occurs during the parse, but application defined error 
      *   handlers are not required to do so. 
      */
-    public ASModel parseASInputSource(DOMInputSource is)
+    public ASModel parseASInputSource(DOMInput is)
                                       throws DOMASException, Exception;
 
 }
@@ -23,9 +23,9 @@
     /**
-     *  Associate an <code>ASModel</code> with a <code>DOMBuilder</code>. This 
+     *  Associate an <code>ASModel</code> with a <code>DOMParser</code>. This
      * <code>ASModel</code> will be used by the "
      * <code>validate-if-schema</code>" and "
@@ -33,7 +33,7 @@
     public ASModel getAbstractSchema();
     /**
-     *  Associate an <code>ASModel</code> with a <code>DOMBuilder</code>. This 
+     *  Associate an <code>ASModel</code> with a <code>DOMParser</code>. This
      * <code>ASModel</code> will be used by the "
      * <code>validate-if-schema</code>" and "
Index: xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASWriter.java
===================================================================
RCS file: /home/cvspublic/xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASWriter.java,v
retrieving revision 1.3
diff -u -w -r1.3 DOMASWriter.java
--- xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASWriter.java	24 Mar 2003 20:27:12 -0000	1.3
+++ xml-xerces/java/src/org/apache/xerces/dom3/as/DOMASWriter.java	29 Jul 2003 12:47:32 -0000
@@ -12,7 +12,7 @@
 
 package org.apache.xerces.dom3.as;
 
-import org.w3c.dom.ls.DOMWriter;
+import org.w3c.dom.ls.DOMSerializer;
 
 /**
  * @deprecated
@@ -26,11 +26,11 @@
  * Abstract Schema. DOMASWriter is applied to serialize a single Abstract 
  * Schema. Serializing a document with an active Internal Abstract Schema 
  * will serialize this internal Abstract Schema with the document as it is 
  * part of the Document (see <code>DOMWriter</code>). 
  * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-ASLS-20011025'>Document Object Model (DOM) Level 3 Abstract Schemas and Load
 and Save Specification</a>.
  */
-public interface DOMASWriter extends DOMWriter {
+public interface DOMASWriter extends DOMSerializer {
     /**
      *  Write out the specified Abstract Schema to the specified destination. 
      * Does it write a DTD or an XML Schema (or something else)? Is it 
@@ -26,11 +26,11 @@
  * Schema. Serializing a document with an active Internal Abstract Schema 
  * will serialize this internal Abstract Schema with the document as it is 
- * part of the Document (see <code>DOMWriter</code>). 
+ * part of the Document (see <code>DOMSerializer</code>).
  * <p>See also the <a href='http://www.w3.org/TR/2001/WD-DOM-Level-3-ASLS-20011025'>Document Object Model (DOM) Level 3 Abstract Schemas and Load
 and Save Specification</a>.